@@ -6,12 +6,10 @@ Library for importing, exporting and doing simple operations on triangular meshe
 from hashlib import new
 from . import augment
 from trimesh import Trimesh
-import sys
 
 class CIRmesh(Trimesh):
 
     def __init__(self):
-        sys.setrecursionlimit(1500000000)
         super().__init__()
 
     def fixNonWatertight(self, mesh):
